@@ -2,7 +2,7 @@
 /**
  *  @brief Class to define functional chaos
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -20,8 +20,7 @@
  */
 #include "persalys/FunctionalChaosAnalysis.hxx"
 
-#include "persalys/MetaModel.hxx"
-
+#include <openturns/JointDistribution.hxx>
 #include <openturns/LinearEnumerateFunction.hxx>
 #include <openturns/FixedStrategy.hxx>
 #include <openturns/LeastSquaresStrategy.hxx>
@@ -131,7 +130,7 @@ Distribution FunctionalChaosAnalysis::getDistribution()
             coll[i] = designOfExperiment_.getPhysicalModel().getInputByName(inputVariablesNames[i]).getDistribution();
           else
             coll[i] = FunctionalChaosAlgorithm::BuildDistribution(effectiveInputSample.getMarginal(i));
-        distribution_ = ComposedDistribution(coll);
+        distribution_ = JointDistribution(coll);
       }
     }
     // build distribution from sample:
@@ -194,7 +193,7 @@ void FunctionalChaosAnalysis::launch()
   const Point stddev(effectiveOutputSample.computeStandardDeviation());
   for (UnsignedInteger i = 0; i < outputDimension; ++ i)
     if (!(stddev[i] > 0.0))
-      throw InvalidArgumentException(HERE) << "No variance for output variable "<< outputVariables[i];
+      throw InvalidArgumentException(HERE) << "No variance for output variable " << outputVariables[i];
 
 
 
@@ -227,6 +226,7 @@ void FunctionalChaosAnalysis::launch()
   buildMetaModel(result_, metamodelFunction);
 
   result_.metaModelOutputSample_ = metamodelFunction(effectiveInputSample);
+  notify("metamodelAvailable");
 
   // post process
   try
@@ -326,10 +326,8 @@ void FunctionalChaosAnalysis::postProcessFunctionalChaosResult(const Sample& inp
 void FunctionalChaosAnalysis::computeAnalyticalValidation(MetaModelAnalysisResult& result, const Sample& inputSample)
 {
   if (stopRequested_)
-  {
-    analyticalValidation_ = false;
     return;
-  }
+
   informationMessage_ = "The analytical validation is running.";
   notify("informationMessageUpdated");
 
