@@ -2,7 +2,7 @@
 /**
  *  @brief QStandardItem, observer of analysis
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -77,8 +77,13 @@ void AnalysisItem::buildActions()
     convertAction_->setStatusTip(tr("Add the metamodel in the study tree"));
     connect(convertAction_, SIGNAL(triggered()), this, SLOT(appendMetaModelItem()));
     convertAction_->setEnabled(analysis_.getImplementation()->hasValidResult());
-
     appendAction(convertAction_);
+
+    exportAction_ = new QAction(tr("Export metamodel"), this);
+    exportAction_->setStatusTip(tr("Export to an independent Python script"));
+    connect(exportAction_, SIGNAL(triggered()), this, SLOT(exportMetaModel()));
+    exportAction_->setEnabled(analysis_.getImplementation()->hasValidResult());
+    appendAction(exportAction_);
   }
   else if (analysisType == "FieldMonteCarloAnalysis")
   {
@@ -163,7 +168,8 @@ void AnalysisItem::updateAnalysis(const Analysis & analysis)
   getParentStudyItem()->getStudy().getAnalysisByName(analysis.getName()).setImplementationAsPersistentObject(analysis.getImplementation());
 
   // the analysis has not result: disable convertAction_ action and extractDataAction_
-  if (convertAction_) {
+  if (convertAction_)
+  {
     convertAction_->setEnabled(analysis_.hasValidResult());
     emit numberMetamodelChanged(analysis_.hasValidResult());
   }
@@ -230,6 +236,29 @@ void AnalysisItem::appendMetaModelItem()
 }
 
 
+void AnalysisItem::exportMetaModel()
+{
+  FunctionalChaosAnalysis * chaos = dynamic_cast<FunctionalChaosAnalysis*>(analysis_.getImplementation().get());
+  KrigingAnalysis * kriging = dynamic_cast<KrigingAnalysis*>(analysis_.getImplementation().get());
+  PolynomialRegressionAnalysis * regression = dynamic_cast<PolynomialRegressionAnalysis*>(analysis_.getImplementation().get());
+  PhysicalModel metamodel;
+  if (chaos)
+  {
+    metamodel = chaos->getResult().getMetaModel();
+  }
+  else if (kriging)
+  {
+    metamodel = kriging->getResult().getMetaModel();
+  }
+  else if (regression)
+  {
+    metamodel = regression->getResult().getMetaModel();
+  }
+
+  emit pythonMetamodelExportRequested(metamodel);
+}
+
+
 void AnalysisItem::appendDataModelItem()
 {
   if (!getParentStudyItem())
@@ -237,13 +266,18 @@ void AnalysisItem::appendDataModelItem()
 
   DesignOfExperimentEvaluation * doeEval = dynamic_cast<DesignOfExperimentEvaluation*>(analysis_.getImplementation().get());
   DataAnalysisResult result;
-  if(doeEval) {
+  if(doeEval)
+  {
     result = doeEval->getResult();
-  } else {
+  }
+  else
+  {
     MonteCarloAnalysis * analysis  = dynamic_cast<MonteCarloAnalysis*>(analysis_.getImplementation().get());
-    if(analysis) {
+    if(analysis)
+    {
       result = analysis->getResult();
-    } else
+    }
+    else
       return;
   }
 
@@ -281,9 +315,11 @@ void AnalysisItem::update(Observable* /*source*/, const String& message)
   if (message == "analysisFinished")
   {
     // if MetaModelAnalysis : enable convertAction_ action
-    if (convertAction_) {
+    if (convertAction_)
+    {
       convertAction_->setEnabled(true);
-      emit numberMetamodelChanged(true);}
+      emit numberMetamodelChanged(true);
+    }
     if (extractDataAction_)
       extractDataAction_->setEnabled(true);
   }
@@ -306,11 +342,16 @@ void AnalysisItem::update(Observable* /*source*/, const String& message)
   {
     convertAction_->setEnabled(analysis_.hasValidResult());
   }
+  else if (message == "metamodelAvailable" && exportAction_)
+  {
+    exportAction_->setEnabled(analysis_.hasValidResult());
+  }
   else if (message == "objectRemoved")
   {
     if (hasChildren())
       qDebug() << "AnalysisItem::update(objectRemoved) has not to contain child\n";
-    if (convertAction_) {
+    if (convertAction_)
+    {
       emit numberMetamodelChanged(false);
     }
     emit removeRequested(row());
