@@ -2,7 +2,7 @@
 /**
  *  @brief QWizardPage to define simulation reliability analysis
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -31,6 +31,7 @@
 #include <openturns/Normal.hxx>
 #include <openturns/Dirac.hxx>
 #include <openturns/NormalCopula.hxx>
+#include <openturns/JointDistribution.hxx>
 
 #include <QVBoxLayout>
 #include <QRadioButton>
@@ -100,7 +101,10 @@ CalibrationIntroPage::CalibrationIntroPage(QWidget * parent)
   methodGroup_->addButton(nonLinearGaussianButton, CalibrationIntroPage::NonlinearGaussian);
   methodLayout->addWidget(nonLinearGaussianButton);
 
-  connect(methodGroup_, static_cast<void(QButtonGroup::*)(QAbstractButton *)>(&QButtonGroup::buttonClicked), [=](QAbstractButton * button){emit methodChanged(methodGroup_->id(button));});
+  connect(methodGroup_, static_cast<void(QButtonGroup::*)(QAbstractButton *)>(&QButtonGroup::buttonClicked), [ = ](QAbstractButton * button)
+  {
+    emit methodChanged(methodGroup_->id(button));
+  });
 
   pageLayout->addWidget(methodBox);
 }
@@ -196,7 +200,10 @@ CalibrationReferencePointPage::CalibrationReferencePointPage(/*const PhysicalMod
   tableView_->setSelectionMode(QAbstractItemView::NoSelection);
   tableModel_ = new CalibrationTableModel(tableView_);
   connect(tableModel_, SIGNAL(modelChanged(PhysicalModel)), this, SIGNAL(modelChanged(PhysicalModel)));
-  connect(tableModel_, &CalibrationTableModel::modelChanged, [=](const PhysicalModel &model) {calibratedLabel_->setText(QString::number(model.getStochasticInputNames().getSize()));});
+  connect(tableModel_, &CalibrationTableModel::modelChanged, [ = ](const PhysicalModel & model)
+  {
+    calibratedLabel_->setText(QString::number(model.getStochasticInputNames().getSize()));
+  });
   tableView_->setModel(tableModel_);
   pageLayout->addWidget(tableView_, 0, Qt::AlignTop);
 
@@ -474,8 +481,8 @@ void CalibrationAnalysisWizard::buildInterface()
 
   // third page : prior distribution
   priorDistPage_ = new CalibrationDistributionPage(tr("Gaussian prior distribution"),
-                                                   tr("Define the covariance matrix of the parameters θ to calibrate."),
-                                                   this);
+      tr("Define the covariance matrix of the parameters θ to calibrate."),
+      this);
 
   connect(refPointPage_, SIGNAL(modelChanged(PhysicalModel)), priorDistPage_, SLOT(updateData(PhysicalModel)));
   setPage(Page_PriorDist, priorDistPage_);
@@ -483,8 +490,8 @@ void CalibrationAnalysisWizard::buildInterface()
 
   // fourth page : observations error distribution
   obsErrorDistPage_ = new CalibrationDistributionPage(tr("Gaussian distribution of the output observations error"),
-                                                      tr("Define the covariance matrix of the output observations error."),
-                                                      this);
+      tr("Define the covariance matrix of the output observations error."),
+      this);
   setPage(Page_ObsErrorDist, obsErrorDistPage_);
 
   initializePages();
@@ -557,7 +564,7 @@ void CalibrationAnalysisWizard::initializePages()
   {
     // build a NormalCopula
     // cannot take only priorDistribution.getCopula() because pm.setCopula
-    // does not manage MarginalDistribution and ComposedCopula
+    // does not manage MarginalDistribution and BlockIndependentCopula
     // We get first the indices of the correlated inputs
     CorrelationMatrix m(analysis_ptr->getPriorDistribution().getSpearmanCorrelation());
     QSet<int> ind;
@@ -671,7 +678,7 @@ Analysis CalibrationAnalysisWizard::getAnalysis() const
   // if least squares algorithm
   else
   {
-    ComposedDistribution distribution(ComposedDistribution::DistributionCollection(refPointPage_->getCalibratedInputs().getSize(), Dirac()));
+    JointDistribution distribution(JointDistribution::DistributionCollection(refPointPage_->getCalibratedInputs().getSize(), Dirac()));
     distribution.setParameter(refPointPage_->getCalibratedInputs());
     calibration.setCalibratedInputs(refPointPage_->getCalibratedInputs().getDescription(),
                                     distribution,
