@@ -2,7 +2,7 @@
 /**
  *  @brief QMenuBar
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -202,12 +202,14 @@ void MenuBar::updateConsoleStatus(const bool visibility)
   settings.setValue("pythonConsoleVisibility", visibility);
 }
 
-void MenuBar::openSettingsWindow() {
+void MenuBar::openSettingsWindow()
+{
   SettingsDialog * settingsDialog = new SettingsDialog(this);
-  connect(settingsDialog, &QDialog::accepted, [=]() {
-      QSettings settings;
-      settings.setValue("nProcesses", QVariant((uint)settingsDialog->getnProcesses()));
-    });
+  connect(settingsDialog, &QDialog::accepted, [ = ]()
+  {
+    QSettings settings;
+    settings.setValue("nProcesses", QVariant((uint)settingsDialog->getnProcesses()));
+  });
   settingsDialog->exec();
 }
 
