@@ -2,7 +2,7 @@
 /**
  *  @brief QObject managing study objects
  *
- *  Copyright 2015-2023 EDF-Phimeca
+ *  Copyright 2015-2024 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -169,8 +169,10 @@ void StudyManager::openMetamodelExportWizard(StudyItem *item, const Analysis& an
 {
   MetaModelExportWizard * wizard = new MetaModelExportWizard(analysis, isGeneralWizard, mainWidget_);
 
-  if (wizard) {
-    if (wizard->exec()) {
+  if (wizard)
+  {
+    if (wizard->exec())
+    {
       FunctionalChaosAnalysis * chaos = dynamic_cast<FunctionalChaosAnalysis*>(wizard->getAnalysis().getImplementation().get());
       if (chaos)
         item->appendMetaModelItem(chaos->getResult().getMetaModel());
@@ -179,7 +181,7 @@ void StudyManager::openMetamodelExportWizard(StudyItem *item, const Analysis& an
         item->appendMetaModelItem(kriging->getResult().getMetaModel());
       PolynomialRegressionAnalysis * linear = dynamic_cast<PolynomialRegressionAnalysis*>(wizard->getAnalysis().getImplementation().get());
       if (linear)
-	item->appendMetaModelItem(linear->getResult().getMetaModel());
+        item->appendMetaModelItem(linear->getResult().getMetaModel());
     }
     delete wizard;
   }
@@ -231,6 +233,7 @@ void StudyManager::createAnalysisWindow(AnalysisItem* item, const bool createCon
     connect(item, SIGNAL(windowRequested(AnalysisItem*, bool)), this, SLOT(createAnalysisWindow(AnalysisItem*, bool)));
     connect(item, SIGNAL(wizardRequested(StudyItem*, Analysis)), this, SLOT(openAnalysisWizard(StudyItem*, Analysis)));
     connect(item, SIGNAL(doeEvaluationWizardRequested(Analysis)), this, SLOT(openDesignOfExperimentEvaluationWizard(Analysis)));
+    connect(item, SIGNAL(pythonMetamodelExportRequested(PhysicalModel)), this, SLOT(exportMetamodelPython(PhysicalModel)));
   }
 
   // do removeSubWindow if the analysis run method has been launched from a Python script
@@ -303,9 +306,9 @@ void StudyManager::importPythonScript(const QString &fileToImport)
   QString fileName = fileToImport;
   if (fileName.isEmpty())
     fileName = QFileDialog::getOpenFileName(mainWidget_,
-                           tr("Import Python..."),
-                           FileTools::GetCurrentDir(),
-                           tr("Python source files (*.py)"));
+                                            tr("Import Python..."),
+                                            FileTools::GetCurrentDir(),
+                                            tr("Python source files (*.py)"));
 
   if (!fileName.isEmpty())
   {
@@ -349,6 +352,26 @@ void StudyManager::exportPythonScript()
 }
 
 
+void StudyManager::exportMetamodelPython(const PhysicalModel & metamodel)
+{
+  AnalysisItem * item = qobject_cast<AnalysisItem *>(sender());
+
+  if (!item)
+  {
+    qDebug() << "StudyManager::exportMetamodelPython : item NULL\n";
+    showErrorMessage(tr("Can not export the current study"));
+    return;
+  }
+
+  const QString fileName = QFileDialog::getSaveFileName(mainWidget_,
+                           tr("Export Python..."),
+                           FileTools::GetCurrentDir() + QDir::separator() + item->data(Qt::DisplayRole).toString() + QString(".py"),
+                           tr("Python source files (*.py)"));
+
+  if (!fileName.isEmpty())
+    metamodel.exportStandalonePythonScript(fileName.toStdString());
+}
+
 // --------------- SAVE FILE ---------------
 
 void StudyManager::saveCurrent()
